@@ -11,7 +11,7 @@
 #define PANGOMM_MAJOR_VERSION 2
 
 /* Minor version number of pangomm. */
-#define PANGOMM_MINOR_VERSION 52
+#define PANGOMM_MINOR_VERSION 48
 
 /* Micro version number of pangomm. */
 #define PANGOMM_MICRO_VERSION 0
@@ -24,10 +24,8 @@
 #ifdef PANGOMM_DLL
 # if defined(PANGOMM_BUILD)
 #  define PANGOMM_API __declspec(dllexport)
-# elif !defined (__GNUC__)
+# else
 #  define PANGOMM_API __declspec(dllimport)
-# else /* don't dllimport classes/methods on GCC/MinGW */
-#  define PANGOMM_API
 # endif /* PANGOMM_BUILD - _WINDLL */
 #else
 /* Build a static library or a non-native-Windows library */
